\name{stepArchetypesMod}
\alias{stepArchetypesMod}
\title{
Slight modification of the original function stepArchetypes
}
\description{
This is a slight modification of the original \code{\link{stepArchetypes}} function of the R package \pkg{archetypes} to apply the archetypoids algorithm to the raw data. The \code{\link{stepArchetypes}} function standardizes the data by default and this option is not always desired.
}
\usage{
stepArchetypesMod(data,k,nrep=3,verbose=TRUE)
}
\arguments{
\item{data}{
Data to obtain archetypes.
}
\item{k}{
Number of archetypes to compute, from 1 to \code{k}.
}
\item{nrep}{
For each \code{k} run \code{\link{archetypes}} \code{nrep} times.
}
\item{verbose}{
If TRUE, the progress during exection is shown.
}
}
\value{
A list with \code{k} elements. Each element is a list of class attribute \code{\link{stepArchetypes}} with \code{nrep} elements.
}
\seealso{
\code{\link{stepArchetypes}}
}
\examples{
\dontrun{
#Cockpit design problem
#First, we read and preprocess the database USAF 1967 (Zehner et al (1993).).
m <- dataUSAF
#Variable selection:
sel <- c(48,40,39,33,34,36)
#Changing to inches: 
mpulg <- m[,sel] / (10 * 2.54)

#Data pre-processing:
preproc <- accommodation(mpulg,TRUE,0.95,TRUE)

#For reproducing results, seed for randomness:
set.seed(2010) 
#Run archetypes algorithm repeatedly from 1 to numArch archetypes:
numArch <- 10 ; nrep <- 3
lass <- stepArchetypesMod(data=preproc$data,k=1:numArch,verbose=FALSE,nrep=nrep)  
}
}
\keyword{array}