\name{stepArchetypoids}
\alias{stepArchetypoids}
\title{
Run the archetypoids algorithm several times
}
\description{
This is a function that allows to execute the \code{\link{archetypoids}} algorithm repeatedly. It is inspired by the \code{\link{stepArchetypes}} function of the R package \pkg{archetypes}.
}
\usage{
stepArchetypoids(i,nearest,data,ArchObj,sequ,aux)
}
\arguments{
\item{i}{
Number of archetypoids to obtain.
}
\item{nearest}{
Initial vector of archetypoids. A logical value: if TRUE the \emph{nearest} vector is calculated; if FALSE, the \emph{which_alpha} vector is calculated. See \code{nearest} argument of \code{\link{archetypoids}}.
}
\item{data}{
Data set in which to look for the archetypoids.
}
\item{ArchObj}{
The list returned by the function \code{\link{stepArchetypesMod}}. This function is a slight modification of the original \code{stepArchetypes} function of the R package \pkg{archetypes} to apply the archetypoids algorithm to the raw data. The \code{stepArchetypes} function standardizes the data by default and this option is not always desired.
}
\item{sequ}{
Logical value. It indicates whether a sequence of archetypoids (TRUE) or only a single number of them (FALSE) is computed.
}
\item{aux}{
If sequ=FALSE, this value is equal to i-1 since for a single number of archetypoids, the list associated with the archetype object only has an element.
}
}
\value{
A list with the following elements:

\emph{archet}: Final vector of k archetypoids.

\emph{rss}: Residual sum of squares corresponding to the final vector of k archetypoids.

\emph{inits}: Vector of initial archetypoids.
}
\note{
It may be happen that the \code{\link{archetypes}} algorithm do not find results for \emph{k} archetypes. In this case, it is not possible to calculate the vector of the nearest individuals and this function will return an error message. 
}
\seealso{
\code{\link{archetypoids}}, \code{\link{archetypes}}, \code{\link{stepArchetypes}}
}
\examples{
\dontrun{
#Cockpit design problem
m <- dataUSAF
#Variable selection:
sel <- c(48,40,39,33,34,36)
#Changing to inches: 
mpulg <- m[,sel] / (10 * 2.54)

#Data pre-processing:
preproc <- accommodation(mpulg,TRUE,0.95,TRUE)

#Computation of archetypes and archetypoids:
#For reproducing results, seed for randomness:
set.seed(2010) 
#Run archetypes algorithm repeatedly from 1 to numArch archetypes:
numArch <- 10 ; nrep <- 20
lass <- stepArchetypesMod(data=preproc$data,k=1:numArch,verbose=FALSE,nrep=nrep)  

#Run archetypoids algorithm repeatedly from 1 to numArch archetypes:
for(i in 1:numArch){
  temp <-  stepArchetypoids(i,TRUE,preproc$data,lass,sequ=TRUE)
  filename <- paste("res", i, sep="")
  assign(filename,temp)
  save(list=c(filename),file=paste(filename, ".RData", sep="")) 
}  

for(i in 1:numArch){
  temp <-  stepArchetypoids(i,FALSE,preproc$data,lass,sequ=TRUE)
  filename <- paste("res", i, "_which",sep="")
  assign(filename,temp)
  save(list=c(filename),file=paste(filename, ".RData", sep=""))
}
}
}
\keyword{array}