#Loading the functions to calculate real archetypes (set the working directory where the functions and data to 
#load are placed): 
source("Functions_to_calculate_real_archetypes_with_swap2.R")
source("stepArchetypesMod.R")
source("stepArchetypoids.R")

#First, we read and preprocess the database USAF 1967 (Zehner et al.):
m <- read.table('med1967.dat', sep = " ")
#Variable selection:
sel <- c(48, 40 ,39, 33, 34, 36)
#Changing to inches: 
mpulg <- m[,sel] / (10 * 2.54)
#Standarizing (normalizing):
smpulg <- scale(mpulg, center = sapply(mpulg,mean), scale = sapply(mpulg,sd)) 

#Next, we remove the more extreme 5% data using the Mahalanobis distance.
Sx <- cov(smpulg)
D2 <- mahalanobis(smpulg, colMeans(smpulg), Sx)

#Individuals considered for covering 95%:
qlchi <- which(D2 <= qchisq(0.95, df = dim(mpulg)[2])) 
#Database with the 6 variables and the selected individuals:
lsmpulg <- smpulg[qlchi,] 

#Computation of archetypes and archetypoids:
library("archetypes")
#For reproducing results, seed for randomness:
set.seed(2010) 
#Run archetypes algorithm repeatedly from 1 to 10 archetypes:
lass10 <- stepArchetypesMod(data = lsmpulg, k = 1:10, verbose = FALSE, nrep = 20)  

rss_lass <- matrix(0,nrow=10,ncol=20)
for(i in 1:10){
  for(j in 1:20){
    rss_lass[i,j] <- lass10[[i]][[j]]$rss
  }
}
(rss_lass_def <- apply(rss_lass,1,min,na.rm=T))
# [1] 0.038629643 0.022002653 0.012380776 0.011507501 0.009948760 0.008220197 0.007399731 0.006786820 0.006345943
# [10] 0.005408868
rss_lass_def <- c(0.038629643, 0.022002653, 0.012380776, 0.011507501, 0.009948760, 
                  0.008220197, 0.007399731, 0.006786820, 0.006345943, 0.005408868)


for(i in 1:10){
  temp <-  stepArchetypoids(i,TRUE,lsmpulg,lass10,sequ=TRUE)
  filename <- paste("res", i, sep="")
  assign(filename,temp)
  save(list=c(filename),file=paste(filename, ".RData", sep="")) 
}  

for(i in 1:10){
  temp <-  stepArchetypoids(i,FALSE,lsmpulg,lass10,sequ=TRUE)
  filename <- paste("res", i, "_which",sep="")
  assign(filename,temp)
  save(list=c(filename),file=paste(filename, ".RData", sep=""))
}  

for(i in 1:10){
 ai <- bestModel(lass10[[i]])
 ini_arch=c()

 for (j in 1:i){
  ini_arch[j]=which.max(ai$betas[j,])
 }

 temp <- realArchetypes(lsmpulg,huge = 200, i, ini_arch)
 temp
 filename <- paste("res", i, "_whichbe",sep="")
 assign(filename,temp)
 save(list=c(filename),file=paste(filename, ".RData", sep=""))
}  

#Screeplot Furthstsum (computed in Matlab)
furth=list(i1=1,i2=c( 1421      ,  1652), i3=c(187     ,   1114     ,   1560),
i4=c(1421  ,      1114   ,     1560  ,       187),i5=c( 1560   ,   1652   ,   1421  ,    1114   ,    611),
i6=c(1268      ,   187   ,     2027    ,    1652   ,     1421  ,      1114),
i7=c(1114    ,     611   ,      187  ,      2027   ,     1560 ,       1652  ,      1421),
i8=c(1421     ,   1114      ,  1268     ,    187    ,    2027   ,     1691   ,     1560  ,      1652),
i9=c( 1652    ,    1421  ,      1114      ,  1268     ,    187      ,  2027     ,   1691  ,       611     ,   1560),
i10=c(1560    ,    1652  ,      1421  ,      1114 ,       1268    ,     187  ,      2027  ,      1691  ,      1432 ,       1918))

for(i in 1:10){
 ini_arch=furth[[i]]
 temp <- realArchetypes(lsmpulg,huge = 200, i, ini_arch)
 temp
 filename <- paste("res", i, "_fu",sep="")
 assign(filename,temp)
 save(list=c(filename),file=paste(filename, ".RData", sep=""))
}  


######
#Numerical and graphical results:
for(i in 1:10){
  load(paste("res", i, ".RData", sep = ""))
}
rss_step <- c()
for (i in 1:10){
  rss_step[i] <- get(paste("res", i, sep = ""))[[2]]
}
(rss_step <- as.numeric(rss_step))


for(i in 1:10){
  load(paste("res", i, "_which.RData", sep = ""))
}
rss_step_which <- c()
for (i in 1:10){
  rss_step_which[i] <- get(paste("res", i, "_which", sep = ""))[[2]]
}
(rss_step_which <- as.numeric(rss_step_which))


for(i in 1:10){
  load(paste("res", i, "_whichbe.RData", sep = ""))
}
rss_step_whichbe <- c()
for (i in 1:10){
  rss_step_whichbe[i] <- get(paste("res", i, "_whichbe", sep = ""))[[2]]
}
(rss_step_whichbe <- as.numeric(rss_step_whichbe))


for(i in 1:10){
  load(paste("res", i, "_fu.RData", sep = ""))
}
rss_step_fu <- c()
for (i in 1:10){
  rss_step_fu[i] <- get(paste("res", i, "_fu", sep = ""))[[2]]
}
(rss_step_fu <- as.numeric(rss_step_fu))


plot(1:10,rss_lass_def,xaxt="n",ylim=c(0.005,0.040),xlab="Archetypes/Archetypoids",ylab="RSS",type="b") 
points(1:10,rss_step,type="b",col="red") 
points(1:10,rss_step_which,type="b",col="blue",lty=2)
points(1:10,rss_step_whichbe,type="b", col="green",lty=6)
points(1:10,rss_step_fu,type="b", col="magenta",lty=3)
axis(1,at=1:10,labels=1:10)
legend("topright",c("Archetypes",
                    expression(paste("Archetypoids from ", cand[ns])),
                    expression(paste("Archetypoids from ", cand[alpha])),
                    expression(paste("Archetypoids from ", cand[beta])),
                    expression(paste("Archetypoids from ", cand[FS]))),
                               lty = c(1,1,2,6,3),
                               col=c("black","red","blue","green3","magenta"),
                               text.col=c("black","red","blue","green3","magenta"))



#ARCHETYPOID PILOTS FOR K=3:
res3
#[[1]]
#[1] 2177 2240 1691
#[[2]]
#[1] 0.01283086
#[[3]]
#[1]  511  314 1691
res3_which
#[[1]]
#[1] 1632 1822   52
#[[2]]
#[1] 0.01238504
#[[3]]
#[1] 1421  314 1691

#Function to obtain the percentile plots:
.perc <- function(x, data, digits = 0) {
  Fn <- ecdf(data)
  round(Fn(x) * 100, digits = digits)
}
#Function to calculate the percentiles of the archetypes for each variable:
calc_perc <- function(column,indiv){
  .perc(lsmpulg[indiv,colnames(lsmpulg)[column]], as.matrix(lsmpulg[,colnames(lsmpulg)[column]]))
}

#Percentiles from 2 to 10 nearest archetypoids:
percs <- list() #List whose components save the percentiles of the corresponding number of archetypoids.
for(i in 2:10){
  percs[[i]] <- list()
  aux <- get(paste("res", i, sep = ""))[[1]]
  for(j in 1:length(aux)){
    percs[[i]][[j]] <- sapply(1:dim(lsmpulg)[2], calc_perc, aux[j])
  }
}
for(i in 2:10){
  m <- matrix(unlist(percs[[i]]), nrow=6, ncol=length(percs[[i]]), byrow=F)
  barplot(m,beside=TRUE,main = paste(i, " archetypoids (from nearest)", sep = ""),ylim=c(0,100),ylab="Percentile")
}

#Percentiles from 2 to 10 which archetypoids:
percs <- list() 
for(i in 2:10){
  percs[[i]] <- list()
  aux <- get(paste("res", i, "_which", sep = ""))[[1]]
  for(j in 1:length(aux)){
    percs[[i]][[j]] <- sapply(1:dim(lsmpulg)[2], calc_perc, aux[j])
  }
}
for(i in 2:10){
  m <- matrix(unlist(percs[[i]]), nrow=6, ncol=length(percs[[i]]), byrow=F)
  barplot(m,beside=TRUE,main = paste(i, " archetypoids (from which)", sep = ""),ylim=c(0,100),ylab="Percentile")
}
