function [ d ] = metrik( w,V,art )
% This function calculates the distance d between a point w and alle ohter
% points in V depending on the chosen metric
% Input:  w - Point (nx1)
%         V - Data matrix (nxm)
%       art - Kind of metric, choose from: ['L2','L1','cosine','KL','Hellinger'] (string)
% Output: d - distance vector (1xm)
%
% Authors: Julian Horst und Sebastian Riedel
% Date: 17.11.2012

[N,~] = size(V);
switch art
    case 'l2'
        d = sqrt(sum((V-repmat(w,N,1)).^2,2));
    case 'l1'
        d = sum(abs((V-repmat(w,N,1))),2);
    case 'cosine'
        d = 1 - (sum((V.*repmat(w,N,1)),2))./(sqrt(sum(V.^2,2)).*sqrt(sum((repmat(w,N,1)).^2,2)));
    case 'kl'
        d = sum(((-repmat(w,N,1).*log(V))-(-repmat(w,N,1).*log(repmat(w,N,1)))),2);
    case 'hellinger'
        d = sum((sqrt(V)-repmat(sqrt(w),N,1)).^2,2);
    otherwise
        disp('Unknown method.')

end

